@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/r128_accel.c,v 1.17 2003/10/03 20:11:11 herrb Exp $ */
 /*
  * Copyright 1999, 2000 ATI Technologies Inc., Markham, Ontario,
  *                      Precision Insight, Inc., Cedar Park, Texas, and
@@ -84,6 +83,8 @@
 #define R128_TRAPEZOIDS 0       /* Trapezoids don't work               */
 
 				/* Driver data structures */
+#include <errno.h>
+
 #include "r128.h"
 #include "r128_reg.h"
 #include "r128_probe.h"
@@ -122,7 +123,7 @@ static struct {
     { R128_ROP3_ONE,  R128_ROP3_ONE  }  /* GXset          */
 };
 
-extern int gR128EntityIndex;
+extern int getR128EntityIndex(void);
 
 /* Flush all dirty data in the Pixel Cache to memory. */
 void R128EngineFlush(ScrnInfoPtr pScrn)
@@ -219,6 +220,9 @@ void R128WaitForIdle(ScrnInfoPtr pScrn)
 		   INREG(R128_GUI_PROBE)));
 	xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
 		   "Idle timed out, resetting engine...\n");
+#ifdef XF86DRI
+        R128CCE_STOP(pScrn, info);
+#endif
 	R128EngineReset(pScrn);
 #ifdef XF86DRI
 	R128CCE_RESET(pScrn, info);
@@ -1842,7 +1846,7 @@ static void R128MMIOAccelInit(ScrnInfoPtr pScrn, XAAInfoRecPtr a)
         DevUnion* pPriv;
         R128EntPtr pR128Ent;
         pPriv = xf86GetEntityPrivate(pScrn->entityList[0],
-                gR128EntityIndex);
+                getR128EntityIndex());
         pR128Ent = pPriv->ptr;
         
         /*if there are more than one devices sharing this entity, we
