@@ -176,6 +176,9 @@ static Bool RADEONGetATOMConnectorInfoFromBIOS (ScrnInfoPtr pScrn)
 		case RADEON_LCD_GPIO_MASK:
 		    info->BiosConnector[i].DDCType = DDC_LCD;
 		    break;
+		case RADEON_MDGPIO_EN_REG:
+		    info->BiosConnector[i].DDCType = DDC_GPIO;
+		    break;
 		default:
 		    info->BiosConnector[i].DDCType = DDC_NONE_DETECTED;
 		    break;
@@ -254,6 +257,23 @@ static Bool RADEONGetLegacyConnectorInfoFromBIOS (ScrnInfoPtr pScrn)
 		info->BiosConnector[i].DDCType = DDC_MONID;
 	    }
 
+	    /* XPRESS desktop chips seem to have a proprietary connector listed for
+	     * DVI-D, try and do the right thing here.
+	    */
+	    if ((!info->IsMobility) &&
+		(info->BiosConnector[i].ConnectorType == CONNECTOR_PROPRIETARY)) {
+		xf86DrvMsg(pScrn->scrnIndex, X_WARNING,
+			   "Proprietary connector found, assuming DVI-D\n");
+		info->BiosConnector[i].DACType = DAC_NONE;
+		info->BiosConnector[i].TMDSType = TMDS_EXT;
+		info->BiosConnector[i].ConnectorType = CONNECTOR_DVI_D;
+	    }
+
+	    if (info->BiosConnector[i].ConnectorType >= CONNECTOR_UNSUPPORTED) {
+		xf86DrvMsg(pScrn->scrnIndex, X_WARNING, "Unknown connector type: %d!\n",
+			   info->BiosConnector[i].ConnectorType);
+		info->BiosConnector[i].valid = FALSE;
+	    }
 
 	}
     } else {
@@ -277,7 +297,7 @@ static Bool RADEONGetLegacyConnectorInfoFromBIOS (ScrnInfoPtr pScrn)
 		    tmp1 = RADEON_BIOS8(tmp0+2) & 0x07;
 		    if (tmp1) {	    
 			info->BiosConnector[4].DDCType	= tmp1;      
-			if (info->BiosConnector[4].DDCType > DDC_LCD) {
+			if (info->BiosConnector[4].DDCType > DDC_GPIO) {
 			    xf86DrvMsg(pScrn->scrnIndex, X_WARNING,
 				       "Unknown DDCType %d found\n",
 				       info->BiosConnector[4].DDCType);
